=======================
Django Google Drive API
=======================

Django integration with `Google Drive API <https://developers.google.com/drive/v3/reference/>`_.

Forked from https://github.com/torre76/django-googledrive-storage to getting
more benefits from Google Drive API without being constrained  by
`Django Storage API <https://docs.djangoproject.com/en/1.7/ref/files/storage/>`_.
